@@ -19,43 +19,66 @@ fragment errorFragment on PythonError {
 STEP_EVENT_FRAGMENTS = (
     ERROR_FRAGMENT
     + """
-fragment metadataEntryFragment on EventMetadataEntry {
+fragment metadataEntryFragment on MetadataEntry {
   __typename
   label
   description
-  ... on EventFloatMetadataEntry {
+  ... on FloatMetadataEntry {
     floatValue
   }
-  ... on EventIntMetadataEntry {
+  ... on IntMetadataEntry {
     intRepr
   }
-  ... on EventJsonMetadataEntry {
+  ... on JsonMetadataEntry {
     jsonString
   }
-  ... on EventMarkdownMetadataEntry {
+  ... on MarkdownMetadataEntry {
     mdStr
   }
-  ... on EventPathMetadataEntry {
+  ... on PathMetadataEntry {
     path
   }
-  ... on EventPythonArtifactMetadataEntry {
+  ... on PythonArtifactMetadataEntry {
     module
     name
   }
-  ... on EventTextMetadataEntry {
+  ... on TextMetadataEntry {
     text
   }
-  ... on EventUrlMetadataEntry {
+  ... on UrlMetadataEntry {
     url
   }
-  ... on EventPipelineRunMetadataEntry  {
+  ... on PipelineRunMetadataEntry  {
     runId
   }
-  ... on EventAssetMetadataEntry  {
+  ... on AssetMetadataEntry  {
     assetKey {
       path
     }
   }
+  ... on TableMetadataEntry  {
+    table {
+      records
+      schema {
+        constraints { other }
+        columns {
+          name
+          type
+          constraints { nullable unique other }
+        }
+      }
+    }
+  }
+  ... on TableSchemaMetadataEntry  {
+    schema {
+      constraints { other }
+      columns {
+        name
+        type
+        constraints { nullable unique other }
+      }
+    }
+  }
 }
 
 fragment stepEventFragment on StepEvent {
@@ -138,13 +161,11 @@ fragment stepEventFragment on StepEvent {
       }
     }
   }
-  ... on StepMaterializationEvent {
-    materialization {
-      label
-      description
-      metadataEntries {
-        ...metadataEntryFragment
-      }
+  ... on MaterializationEvent {
+    label
+    description
+    metadataEntries {
+      ...metadataEntryFragment
     }
   }
 
@@ -172,14 +193,12 @@ fragment messageEventFragment on MessageEvent {
   level
   eventType
   ...stepEventFragment
-  ... on StepMaterializationEvent {
-    materialization {
-      label
-      description
-      metadataEntries {
-        __typename
-        ...metadataEntryFragment
-      }
+  ... on MaterializationEvent {
+    label
+    description
+    metadataEntries {
+      __typename
+      ...metadataEntryFragment
     }
   }
   ... on ExecutionStepFailureEvent {
@@ -262,6 +281,7 @@ mutation($executionParams: ExecutionParams!) {
         status
         runConfigYaml
         mode
+        resolvedOpSelection
       }
     }
     ... on ConflictingExecutionParamsError {
