@@ -1,11 +1,16 @@
-from dagster import check
-from dagster.core.storage.compute_log_manager import ComputeIOType
-from dagster.core.storage.pipeline_run import PipelineRunStatus
-from dagster.serdes import serialize_dagster_namedtuple
-from dagster.utils.error import serializable_error_info_from_exc_info
+import sys
+
 from graphql.execution.base import ResolveInfo
 from rx import Observable
 
+from dagster import check
+from dagster.core.events import DagsterEventType, EngineEventData
+from dagster.core.instance import DagsterInstance
+from dagster.core.storage.compute_log_manager import ComputeIOType
+from dagster.core.storage.pipeline_run import PipelineRunStatus, RunsFilter
+from dagster.serdes import serialize_dagster_namedtuple
+from dagster.utils.error import serializable_error_info_from_exc_info
+
 from ..external import ExternalPipeline, ensure_valid_config, get_external_pipeline_or_raise
 from ..fetch_runs import is_config_valid
 from ..pipeline_run_storage import PipelineRunObservableSubscribe
@@ -18,49 +23,48 @@ from .backfill import (
 from .launch_execution import launch_pipeline_execution, launch_pipeline_reexecution
 
 
-def _force_mark_as_canceled(graphene_info, run_id):
-    from ...schema.pipelines.pipeline import GraphenePipelineRun
-    from ...schema.roots.mutation import GrapheneTerminatePipelineExecutionSuccess
+def _force_mark_as_canceled(instance, run_id):
+    from ...schema.pipelines.pipeline import GrapheneRun
+    from ...schema.roots.mutation import GrapheneTerminateRunSuccess
 
-    instance = graphene_info.context.instance
+    reloaded_record = instance.get_run_records(RunsFilter(run_ids=[run_id]))[0]
 
-    reloaded_run = instance.get_run_by_id(run_id)
-
-    if not reloaded_run.is_finished:
+    if not reloaded_record.pipeline_run.is_finished:
         message = (
             "This pipeline was forcibly marked as canceled from outside the execution context. The "
             "computational resources created by the run may not have been fully cleaned up."
         )
-        instance.report_run_canceled(reloaded_run, message=message)
-        reloaded_run = instance.get_run_by_id(run_id)
+        instance.report_run_canceled(reloaded_record.pipeline_run, message=message)
+        reloaded_record = instance.get_run_records(RunsFilter(run_ids=[run_id]))[0]
 
-    return GrapheneTerminatePipelineExecutionSuccess(GraphenePipelineRun(reloaded_run))
+    return GrapheneTerminateRunSuccess(GrapheneRun(reloaded_record))
 
 
 @capture_error
-def terminate_pipeline_execution(graphene_info, run_id, terminate_policy):
-    from ...schema.errors import GraphenePipelineRunNotFoundError
-    from ...schema.pipelines.pipeline import GraphenePipelineRun
+def terminate_pipeline_execution(instance, run_id, terminate_policy):
+    from ...schema.errors import GrapheneRunNotFoundError
+    from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.roots.mutation import (
-        GrapheneTerminatePipelineExecutionFailure,
-        GrapheneTerminatePipelineExecutionSuccess,
-        GrapheneTerminatePipelinePolicy,
+        GrapheneTerminateRunFailure,
+        GrapheneTerminateRunPolicy,
+        GrapheneTerminateRunSuccess,
     )
 
-    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    check.inst_param(instance, "instance", DagsterInstance)
     check.str_param(run_id, "run_id")
 
-    instance = graphene_info.context.instance
-    run = instance.get_run_by_id(run_id)
+    records = instance.get_run_records(RunsFilter(run_ids=[run_id]))
 
     force_mark_as_canceled = (
-        terminate_policy == GrapheneTerminatePipelinePolicy.MARK_AS_CANCELED_IMMEDIATELY
+        terminate_policy == GrapheneTerminateRunPolicy.MARK_AS_CANCELED_IMMEDIATELY
     )
 
-    if not run:
-        return GraphenePipelineRunNotFoundError(run_id)
+    if not records:
+        return GrapheneRunNotFoundError(run_id)
 
-    pipeline_run = GraphenePipelineRun(run)
+    record = records[0]
+    run = record.pipeline_run
+    graphene_run = GrapheneRun(record)
 
     valid_status = not run.is_finished and (
         force_mark_as_canceled
@@ -68,43 +72,49 @@ def terminate_pipeline_execution(graphene_info, run_id, terminate_policy):
     )
 
     if not valid_status:
-        return GrapheneTerminatePipelineExecutionFailure(
-            run=pipeline_run,
+        return GrapheneTerminateRunFailure(
+            run=graphene_run,
             message="Run {run_id} could not be terminated due to having status {status}.".format(
                 run_id=run.run_id, status=run.status.value
             ),
         )
 
+    if force_mark_as_canceled:
+        try:
+            if instance.run_coordinator and instance.run_coordinator.can_cancel_run(run_id):
+                instance.run_coordinator.cancel_run(run_id)
+        except:
+            instance.report_engine_event(
+                "Exception while attempting to force-terminate run. Run will still be marked as canceled.",
+                pipeline_name=run.pipeline_name,
+                run_id=run.run_id,
+                engine_event_data=EngineEventData(
+                    error=serializable_error_info_from_exc_info(sys.exc_info()),
+                ),
+            )
+        return _force_mark_as_canceled(instance, run_id)
+
     if (
-        graphene_info.context.instance.run_coordinator
-        and graphene_info.context.instance.run_coordinator.can_cancel_run(run_id)
-        and graphene_info.context.instance.run_coordinator.cancel_run(run_id)
+        instance.run_coordinator
+        and instance.run_coordinator.can_cancel_run(run_id)
+        and instance.run_coordinator.cancel_run(run_id)
     ):
+        return GrapheneTerminateRunSuccess(graphene_run)
 
-        return (
-            _force_mark_as_canceled(graphene_info, run_id)
-            if force_mark_as_canceled
-            else GrapheneTerminatePipelineExecutionSuccess(pipeline_run)
-        )
-
-    return (
-        _force_mark_as_canceled(graphene_info, run_id)
-        if force_mark_as_canceled
-        else GrapheneTerminatePipelineExecutionFailure(
-            run=pipeline_run, message="Unable to terminate run {run_id}".format(run_id=run.run_id)
-        )
+    return GrapheneTerminateRunFailure(
+        run=graphene_run, message="Unable to terminate run {run_id}".format(run_id=run.run_id)
     )
 
 
 @capture_error
 def delete_pipeline_run(graphene_info, run_id):
-    from ...schema.errors import GraphenePipelineRunNotFoundError
+    from ...schema.errors import GrapheneRunNotFoundError
     from ...schema.roots.mutation import GrapheneDeletePipelineRunSuccess
 
     instance = graphene_info.context.instance
 
     if not instance.has_run(run_id):
-        return GraphenePipelineRunNotFoundError(run_id)
+        return GrapheneRunNotFoundError(run_id)
 
     instance.delete_run(run_id)
 
@@ -112,7 +122,7 @@ def delete_pipeline_run(graphene_info, run_id):
 
 
 def get_pipeline_run_observable(graphene_info, run_id, after=None):
-    from ...schema.pipelines.pipeline import GraphenePipelineRun
+    from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.pipelines.subscription import (
         GraphenePipelineRunLogsSubscriptionFailure,
         GraphenePipelineRunLogsSubscriptionSuccess,
@@ -123,9 +133,9 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
     check.str_param(run_id, "run_id")
     check.opt_int_param(after, "after")
     instance = graphene_info.context.instance
-    run = instance.get_run_by_id(run_id)
+    records = instance.get_run_records(RunsFilter(run_ids=[run_id]))
 
-    if not run:
+    if not records:
 
         def _get_error_observable(observer):
             observer.on_next(
@@ -136,10 +146,13 @@ def get_pipeline_run_observable(graphene_info, run_id, after=None):
 
         return Observable.create(_get_error_observable)  # pylint: disable=E1101
 
+    record = records[0]
+    run = record.pipeline_run
+
     def _handle_events(payload):
         events, loading_past = payload
         return GraphenePipelineRunLogsSubscriptionSuccess(
-            run=GraphenePipelineRun(run),
+            run=GrapheneRun(record),
             messages=[from_event_record(event, run.pipeline_name) for event in events],
             hasMorePastEvents=loading_past,
         )
