@@ -1,6 +1,8 @@
-from dagster import check
 from graphql.execution.base import ResolveInfo
 
+from dagster import check
+from dagster.core.storage.pipeline_run import RunsFilter
+
 from ..external import get_external_pipeline_or_raise
 from ..utils import ExecutionMetadata, ExecutionParams, capture_error
 from .run_lifecycle import create_valid_pipeline_run
@@ -34,18 +36,20 @@ def do_launch(graphene_info, execution_params, is_reexecuted=False):
     pipeline_run = create_valid_pipeline_run(graphene_info, external_pipeline, execution_params)
 
     return graphene_info.context.instance.submit_run(
-        pipeline_run.run_id, external_pipeline=external_pipeline
+        pipeline_run.run_id,
+        workspace=graphene_info.context,
     )
 
 
 def _launch_pipeline_execution(graphene_info, execution_params, is_reexecuted=False):
-    from ...schema.pipelines.pipeline import GraphenePipelineRun
-    from ...schema.runs import GrapheneLaunchPipelineRunSuccess
+    from ...schema.pipelines.pipeline import GrapheneRun
+    from ...schema.runs import GrapheneLaunchRunSuccess
 
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(execution_params, "execution_params", ExecutionParams)
     check.bool_param(is_reexecuted, "is_reexecuted")
 
     run = do_launch(graphene_info, execution_params, is_reexecuted)
+    records = graphene_info.context.instance.get_run_records(RunsFilter(run_ids=[run.run_id]))
 
-    return GrapheneLaunchPipelineRunSuccess(run=GraphenePipelineRun(run))
+    return GrapheneLaunchRunSuccess(run=GrapheneRun(records[0]))
