@@ -1,9 +1,9 @@
 from collections import defaultdict
-from typing import Dict, List
+from typing import Dict
 
 from graphql.execution.base import ResolveInfo
 
-from dagster import PipelineDefinition, PipelineRunStatus, check
+from dagster import AssetKey, PipelineDefinition, PipelineRunStatus, check
 from dagster.config.validate import validate_config
 from dagster.core.definitions import create_run_config_schema
 from dagster.core.errors import DagsterRunNotFoundError
@@ -11,7 +11,6 @@ from dagster.core.execution.stats import StepEventStatus
 from dagster.core.host_representation import PipelineSelector
 from dagster.core.storage.pipeline_run import PipelineRun, RunsFilter
 from dagster.core.storage.tags import TagType, get_tag_type
-from dagster.utils import utc_datetime_from_timestamp
 
 from .external import ensure_valid_config, get_external_pipeline_or_raise
 from .utils import UserFacingGraphQLError, capture_error
@@ -172,114 +171,36 @@ def get_in_progress_runs_by_step(graphene_info, job_names, step_keys):
     ]
 
 
-def get_asset_run_stats_by_step(graphene_info, asset_nodes):
-    # This is a utility method that gets the latest run that selected an asset,
-    # by searching within the last 5 runs of each job the asset belongs in.
-    # If none of the most recent runs selected the asset, we return back a GrapheneJobRunsCount
-    # object that contains the total number of job runs that have occurred since the latest
-    # asset materialization (or the total number of job runs if the asset has never been
-    # materialized).
-
-    latest_run_by_step = get_latest_asset_run_by_step_key(graphene_info, asset_nodes)
-    assets_to_fetch_run_count = [
-        asset_node
-        for asset_node in asset_nodes
-        if latest_run_by_step.get(asset_node.op_name) == None
-    ]
-    jobs_runs_count = get_asset_runs_count_by_step(graphene_info, assets_to_fetch_run_count)
-
-    return [
-        latest_run_by_step.get(asset_node.op_name, jobs_runs_count.get(asset_node.op_name))
-        for asset_node in asset_nodes
-    ]
-
-
 def get_latest_asset_run_by_step_key(graphene_info, asset_nodes):
     from ..schema.pipelines.pipeline import GrapheneLatestRun, GrapheneRun
 
-    # This method returns the latest run that has occurred for a given step.
-    # Because it is expensive to deserialize PipelineRun objects, we limit this
-    # query to retrieving the last 5 runs per job. If no runs have occurred, we return
-    # a GrapheneLatestRun object with no run. If none of the latest runs contain the
-    # step key, we return None.
-
     instance = graphene_info.context.instance
 
     latest_run_by_step: Dict[str, PipelineRun] = {}
+    latest_run_id_by_asset: Dict[AssetKey, str] = {}
 
-    for asset_node in asset_nodes:
-        job_names = asset_node.job_names
-        step_key = asset_node.op_name
+    for record in instance.get_asset_records([asset.asset_key for asset in asset_nodes]):
+        asset_key = record.asset_entry.asset_key
+        last_run_id = record.asset_entry.last_run_id
+        if last_run_id:
+            latest_run_id_by_asset[asset_key] = last_run_id
 
-        run_records = []
-        for job_name in job_names:
-            run_records.extend(
-                instance.get_run_records(RunsFilter(pipeline_name=job_name), limit=5)
-            )
+    run_records_by_run_id = {}
+    run_ids = list(set(latest_run_id_by_asset.values()))
+    if run_ids:
+        run_records = instance.get_run_records(RunsFilter(run_ids=run_ids))
+        for run_record in run_records:
+            run_records_by_run_id[run_record.pipeline_run.run_id] = run_record
 
-        if len(run_records) == 0:
-            latest_run_by_step[step_key] = GrapheneLatestRun(step_key, None)
-
-        latest_run = None
-        for record in run_records:
-            run = record.pipeline_run
-
-            asset_names = graphene_info.context.instance.get_execution_plan_snapshot(
-                run.execution_plan_snapshot_id
-            ).step_keys_to_execute
-
-            if step_key in asset_names:
-                if latest_run == None or record.create_timestamp > latest_run.create_timestamp:
-                    latest_run = record
-        if latest_run:
-            latest_run_by_step[step_key] = GrapheneLatestRun(step_key, GrapheneRun(latest_run))
-
-    return latest_run_by_step
-
-
-def get_asset_runs_count_by_step(graphene_info, asset_nodes):
-    from ..schema.pipelines.pipeline import GrapheneJobRunsCount
-
-    instance = graphene_info.context.instance
-
-    jobs_runs_count: Dict[str, GrapheneJobRunsCount] = {}
-
-    if len(asset_nodes) == 0:
-        return jobs_runs_count
-
-    step_key_to_job_names: Dict[str, List[str]] = {
-        asset_node.op_name: asset_node.job_names for asset_node in asset_nodes
-    }
-    materializations = instance.get_latest_materialization_events(
-        [asset_node.asset_key for asset_node in asset_nodes]
-    )
-    for asset_node in asset_nodes:
-        event = materializations.get(asset_node.asset_key)
-        step_key = asset_node.op_name
-        job_names = step_key_to_job_names[step_key]
-        runs_count = sum(
-            [
-                instance.get_runs_count(
-                    RunsFilter(
-                        pipeline_name=job_name,
-                        updated_after=utc_datetime_from_timestamp(event.timestamp)
-                        if event
-                        else None,
-                    )
-                )
-                for job_name in job_names
-            ]
+    for asset in asset_nodes:
+        run_id = latest_run_id_by_asset.get(asset.asset_key)
+        step_key = asset.op_name
+        # return run = None when no runs have occurred for the asset
+        latest_run_by_step[step_key] = GrapheneLatestRun(
+            step_key, GrapheneRun(run_records_by_run_id[run_id]) if run_id else None
         )
 
-        # If a materialization has occurred, we subtract one so that the runs count
-        # does not include the run that generated the materialization.
-        if event:
-            runs_count -= 1
-
-        jobs_runs_count[step_key] = GrapheneJobRunsCount(
-            step_key, job_names, runs_count, True if event else False
-        )
-    return jobs_runs_count
+    return [latest_run_by_step.get(asset_node.op_name) for asset_node in asset_nodes]
 
 
 def get_runs_count(graphene_info, filters):
