@@ -1,7 +1,7 @@
 import graphene
 from dagster_graphql.implementation.fetch_runs import (
-    get_asset_run_stats_by_step,
     get_in_progress_runs_by_step,
+    get_latest_asset_run_by_step_key,
 )
 from dagster_graphql.implementation.fetch_solids import get_solid, get_solids
 from dagster_graphql.implementation.loader import RepositoryScopedBatchLoader
@@ -21,8 +21,8 @@ from .partition_sets import GraphenePartitionSet
 from .pipelines.pipeline import (
     GrapheneInProgressRunsByStep,
     GrapheneJob,
+    GrapheneLatestRun,
     GraphenePipeline,
-    GrapheneRunStatsByStep,
 )
 from .repository_origin import GrapheneRepositoryMetadata, GrapheneRepositoryOrigin
 from .schedules import GrapheneSchedule
@@ -169,7 +169,7 @@ class GrapheneRepository(graphene.ObjectType):
     assetNodes = non_null_list(GrapheneAssetNode)
     displayMetadata = non_null_list(GrapheneRepositoryMetadata)
     inProgressRunsByStep = non_null_list(GrapheneInProgressRunsByStep)
-    latestRunByStep = non_null_list(GrapheneRunStatsByStep)
+    latestRunByStep = non_null_list(GrapheneLatestRun)
 
     class Meta:
         name = "Repository"
@@ -274,13 +274,11 @@ class GrapheneRepository(graphene.ObjectType):
         return get_in_progress_runs_by_step(graphene_info, job_names, asset_node_keys)
 
     def resolve_latestRunByStep(self, graphene_info):
-        return get_asset_run_stats_by_step(
+        asset_node = [node for node in self._repository.get_external_asset_nodes() if node.op_name]
+
+        return get_latest_asset_run_by_step_key(
             graphene_info,
-            [
-                asset_node
-                for asset_node in self._repository.get_external_asset_nodes()
-                if asset_node.op_name
-            ],
+            asset_node,
         )
 
 
